@@ -55,23 +55,54 @@ function initDateChoosers(context) {
     $('input.friendly_date', context).datepicker({
         dateFormat: 'd M yy', constrainInput: false, /* showOn: 'button', */ firstDay: 1
     });
+    
+    if(window.overrideDateInputFormat && window.overrideDateInputFormat !='') {
+        $('input.localized_date', context).datepicker({
+            dateFormat: window.overrideDateInputFormat, constrainInput: false, /* showOn: 'button', */ firstDay: 1
+        });
+    } else {
+        $('input.localized_date', context).datepicker({
+            constrainInput: false, /* showOn: 'button', */ firstDay: 1
+        });
+    }
+    
 }
-function initDateChooser(id) {
+function initFriendlyDateChooser(id) {
     $('#' + id).datepicker({
         dateFormat: 'd M yy', constrainInput: false, /* showOn: 'button', */ firstDay: 1
     });
 }
+function initLocalizedDateChooser(id) {
+    if(window.overrideDateInputFormat && window.overrideDateInputFormat !='') {
+        $('#' + id).datepicker({
+            dateFormat: window.overrideDateInputFormat, constrainInput: false, /* showOn: 'button', */ firstDay: 1
+        });
+    } else {
+        $('#' + id).datepicker({
+            constrainInput: false, /* showOn: 'button', */ firstDay: 1
+        });
+    }
+    
+}
 
 function initTimeChoosers(context) {
     $('input.friendly_time', context).timepicker({
         timeFormat: 'g.ia'
     });
+    $('input.localized_time', context).timepicker({
+        timeFormat: 'H:i', maxTime: '23:59'
+    });
 }
-function initTimeChooser(id) {
+function initFriendlyTimeChooser(id) {
     $('#' + id).timepicker({
         timeFormat: 'g.ia'
     });
 }
+function initLocalizedTimeChooser(id) {
+    $('#' + id).timepicker({
+        timeFormat: 'H:i', maxTime: '23:59'
+    });
+}
 
 function initTagField(id, autocompleteUrl) {
     $('#' + id).tagit({
@@ -209,7 +240,11 @@ function InlinePanel(opts) {
 }
 
 function cleanForSlug(val){
-    return val.replace(/\s/g,"-").replace(/[^A-Za-z0-9\-]/g,"").toLowerCase();
+    if(URLify != undefined) { // Check to be sure that URLify function exists
+        return URLify(val, val.length);
+    } else { // If not just do the "replace"
+        return val.replace(/\s/g,"-").replace(/[^A-Za-z0-9\-]/g,"").toLowerCase();
+    }
 }
 
 function initSlugAutoPopulate(){
@@ -232,11 +267,23 @@ function initSlugCleaning(){
 }
 
 function initErrorDetection(){
+    var errorSections = {};
+
+    // first count up all the errors
     $('.error-message').each(function(){
         var parentSection = $(this).closest('section');
 
-        $('.tab-nav a[href=#'+ parentSection.attr('id') +']').addClass('errors');
-    })
+        if(!errorSections[parentSection.attr('id')]){
+            errorSections[parentSection.attr('id')] = 0;
+        }
+
+        errorSections[parentSection.attr('id')] = errorSections[parentSection.attr('id')]+1;
+    });
+
+    // now identify them on each tab
+    for(var index in errorSections) {
+        $('.tab-nav a[href=#'+ index +']').addClass('errors').attr('data-count', errorSections[index]);
+    }    
 }
 
 $(function() {
@@ -253,10 +300,12 @@ $(function() {
     /* Set up behaviour of preview button */
     $('#action-preview').click(function() {
         var previewWindow = window.open($(this).data('placeholder'), $(this).data('windowname'));
-        $.post(
-            $(this).data('action'),
-            $('#page-edit-form').serialize(),
-            function(data, textStatus, request) {
+
+        $.ajax({
+            type: "POST",
+            url: $(this).data('action'),
+            data: $('#page-edit-form').serialize(),
+            success: function(data, textStatus, request) {
                 if (request.getResponseHeader('X-Wagtail-Preview') == 'ok') {
                     previewWindow.document.open();
                     previewWindow.document.write(data);
@@ -267,7 +316,17 @@ $(function() {
                     document.write(data);
                     document.close();
                 }
+            },
+            error: function(xhr, textStatus, errorThrown) {
+                /* If an error occurs, display it in the preview window so that
+                we aren't just showing the spinner forever. We preserve the original
+                error output rather than giving a 'friendly' error message so that
+                developers can debug template errors. (On a production site, we'd
+                typically be serving a friendly custom 500 page anyhow.) */
+                previewWindow.document.open();
+                previewWindow.document.write(xhr.responseText);
+                previewWindow.document.close();
             }
-        );
+        });
     });
 });
