@@ -1,4 +1,3 @@
 from indexed import Indexed
-from search import Search
-from searcher import Searcher
 from signal_handlers import register_signal_handlers
+from backends import get_search_backend
\ No newline at end of file
